@@ -8,13 +8,30 @@ import time
 from datetime import datetime
 try:
     from email.utils import parsedate
-except ImportError: #  Python < 2.5
+except ImportError:  # Python < 2.5
     from email.Utils import parsedate
 
-from tiddlyweb.web.http import HTTP415
+from tiddlyweb.web.http import HTTP415, HTTP400
 from tiddlyweb.util import sha
 
 
+def get_route_value(environ, name):
+    """
+    Retrieve and decode from UTF-8 data provided in WSGI route.
+
+    If name is not present in the route, allow KeyError to raise.
+
+    If the provided data is not URI escaped UTF-8, raise and HTTP400
+    """
+    try:
+        value = environ['wsgiorg.routing_args'][1][name]
+        value = urllib.unquote(value).decode('utf-8')
+    except UnicodeDecodeError, exc:
+        raise HTTP400('incorrect encoding for %s, UTF-8 required: %s',
+                exc)
+    return value
+
+
 def get_serialize_type(environ):
     """
     Look in the environ to determine which serializer
